@@ -80,6 +80,9 @@ FAILEDOPERATION_CONTAINERGROUPKUBERNETEAPIINVOKEERROR = 'FailedOperation.Contain
 # 连接 kube-api-sever 失败。
 FAILEDOPERATION_CONTAINERGROUPKUBERNETECONNECTERROR = 'FailedOperation.ContainergroupKuberneteConnectError'
 
+# 调用 kube-api-server 失败。
+FAILEDOPERATION_CONTAINERGROUPKUBERNETESAPIINVOKEERROR = 'FailedOperation.ContainergroupKubernetesApiInvokeError'
+
 # 调用 kube-api-server 失败。
 FAILEDOPERATION_CONTAINERGROUPKUBERNETESCONNECTERROR = 'FailedOperation.ContainergroupKubernetesConnectError'
 
@@ -329,6 +332,9 @@ INTERNALERROR_CVMCAEMASTERINTERNALERROR = 'InternalError.CvmCaeMasterInternalErr
 # MASTER通道查询失败。
 INTERNALERROR_CVMCAEMASTERNONALIVE = 'InternalError.CvmCaeMasterNonAlive'
 
+# 数据查询失败。
+INTERNALERROR_CVMCAEMASTERQUERYERROR = 'InternalError.CvmCaeMasterQueryError'
+
 # TSF暂时不能响应请求。。
 INTERNALERROR_DISPATCHCOMMONERROR = 'InternalError.DispatchCommonError'
 
@@ -416,6 +422,9 @@ INVALIDPARAMETER_BADREQUEST = 'InvalidParameter.BadRequest'
 # 配置模板名称不符合规范。
 INVALIDPARAMETER_CONFIGTEMPLATENAMEINVALID = 'InvalidParameter.ConfigTemplateNameInvalid'
 
+# TSF MASTER 解包失败。
+INVALIDPARAMETER_CVMCAEMASTERJSONDECODEFAIL = 'InvalidParameter.CvmCaeMasterJsonDecodeFail'
+
 # TSF MASTER 实例状态异常。
 INVALIDPARAMETER_CVMCAEMASTERUNKNOWNINSTANCESTATUS = 'InvalidParameter.CvmCaeMasterUnknownInstanceStatus'
 
@@ -713,6 +722,9 @@ INVALIDPARAMETERVALUE_CVMCAEMASTERAGENTNOTFOUND = 'InvalidParameterValue.CvmCaeM
 # TSF MASTER 部署组中无云主机。
 INVALIDPARAMETERVALUE_CVMCAEMASTERGROUPNOAGENT = 'InvalidParameterValue.CvmCaeMasterGroupNoAgent'
 
+# 任务不存在。
+INVALIDPARAMETERVALUE_CVMCAEMASTERTASKNOTEXIST = 'InvalidParameterValue.CvmCaeMasterTaskNotExist'
+
 # 部署组不存在。
 INVALIDPARAMETERVALUE_DEPLOYGROUPNOTEXISTS = 'InvalidParameterValue.DeployGroupNotExists'
 
